// Copyright (C) 2003 Neil Stevens <neil@qualityassistant.com>
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
// THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
// AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
// CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
// Except as contained in this notice, the name(s) of the author(s) shall not be
// used in advertising or otherwise to promote the sale, use or other dealings
// in this Software without prior written authorization from the author(s).

#include <dcopclient.h>
#include <kapplication.h>
#include <kgenericfactory.h>
#include <kglobal.h>
#include <klocale.h>
#include "popupmenu.h"

namespace Hayes
{
typedef KGenericFactory<Hayes::PopupMenu, KonqPopupMenu> PopupMenuFactory;
}

K_EXPORT_COMPONENT_FACTORY(noatun_hayes, Hayes::PopupMenuFactory("noatun_hayes"));

Hayes::PopupMenu::PopupMenu(KonqPopupMenu *menu, const char *name, const QStringList &)
	: KonqPopupMenuPlugin(menu, name)
{
	// Support exactly one file
	if(menu->fileItemList().count() != 1)
		return;

	// Is this right?
	KGlobal::locale()->insertCatalogue("noatun");

	DCOPClient &client = *kapp->dcopClient();
	if (!client.isAttached())
		client.attach();

	// See if Noatun is running
	if(!client.registeredApplications().contains("noatun"))
		return;

	// See if Hayes is running in Noatun
	if(!client.remoteObjects(QCString("noatun")).contains("Hayes"))
		return;

	// Get playlist URL
	QByteArray replyData;
	QCString replyType;

	if(!client.call(QCString("noatun"), QCString("Hayes"), QCString("playlistDirectory()"),
	   QByteArray(), replyType, replyData))
		return;
	
	if(replyType != QCString("KURL")) return;

	KURL playlistURL;
	QDataStream dataStream(replyData, IO_ReadOnly);
	dataStream >> playlistURL;

	if(playlistURL.isParentOf(menu->url()))
	{
		KAction *hayesAction = new KAction(i18n("Play in Noatun Now"), 0, this, SLOT(play()), actionCollection(), "noatun_hayes");
		addAction(hayesAction);
	}
}

void Hayes::PopupMenu::play(void)
{
	DCOPClient &client = *kapp->dcopClient();
	KURL url = static_cast<KonqPopupMenu *>(parent())->fileItemList().first()->url();

	QByteArray data;
	QDataStream dataStream(data, IO_WriteOnly);
	dataStream << url;

	client.send(QCString("noatun"), QCString("Hayes"), QCString("setCurrent(KURL)"), data);
}

#include "popupmenu.moc"
